@@ -27,29 +27,23 @@
 #include <QCryptographicHash>
 #include <QImage>
 #include <QIcon>
-#include <QPainter>
 #include <QPixmap>
 #include <QUrl>
 #include <QMimeType>
 #include <QMimeDatabase>
 #include <QLibrary>
 #include <QDebug>
-#include <QRandomGenerator>
+#include <QPluginLoader>
 
 #include <KConfigGroup>
 #include <KFileItem>
 #include <KLocalizedString>
-#include <KPluginInfo>
-#include <KPluginLoader>
-#include <KServiceTypeTrader>
 #include <KSharedConfig>
 
-#include <kio/previewjob.h>
-#include <kio/thumbcreator.h>
-#include <kio/thumbdevicepixelratiodependentcreator.h>
-#include <kio/thumbsequencecreator.h>
-#include <kio/previewjob.h>
-#include <kio_version.h>
+#include <KIO/ThumbCreator>
+#include <KIO/ThumbDevicePixelRatioDependentCreator>
+#include <KIO/ThumbSequenceCreator>
+#include <KIO/PreviewJob>
 
 #include <limits>
 #include <QDirIterator>
@@ -234,7 +228,7 @@ void ThumbnailProtocol::get(const QUrl &url)
     } else {
 #ifdef THUMBNAIL_HACK
         if (plugin.isEmpty()) {
-            plugin = pluginForMimeType(m_mimeType);
+            plugin = pluginForMimeType(m_mimeType).fileName();
         }
 
         //qDebug() << "Guess plugin: " << plugin;
@@ -336,42 +330,26 @@ void ThumbnailProtocol::get(const QUrl &url)
     finished();
 }
 
-static QVector<KPluginMetaData> availablePlugins()
-{
-    auto jsonMetaDataPlugins = KPluginMetaData::findPlugins(QStringLiteral("kf5/thumbcreator"));
-    QT_WARNING_PUSH
-    QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
-    QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
-    // TODO KF6 remove this compat codepath
-    const KService::List plugins = KServiceTypeTrader::self()->query(QStringLiteral("ThumbCreator"));
-    for (const auto &plugin : plugins) {
-        if (KPluginInfo info(plugin); info.isValid()) {
-            jsonMetaDataPlugins << info.toMetaData();
-        }
-    }
-    QT_WARNING_POP
-    return jsonMetaDataPlugins;
-}
-
-QString ThumbnailProtocol::pluginForMimeType(const QString& mimeType) {
-    const static auto plugins = availablePlugins();
-    for (const auto &plugin : plugins) {
+KPluginMetaData ThumbnailProtocol::pluginForMimeType(const QString& mimeType) {
+    const QVector<KPluginMetaData> plugins = KIO::PreviewJob::availableThumbnailerPlugins();
+    for (const KPluginMetaData &plugin : plugins) {
         if (plugin.supportsMimeType(mimeType)) {
-            return plugin.fileName();
+            return plugin;
         }
     }
     for (const auto &plugin : plugins) {
         const QStringList mimeTypes = plugin.mimeTypes() + plugin.value(QStringLiteral("ServiceTypes"), QStringList());
         for (const QString& mime : mimeTypes) {
             if(mime.endsWith('*')) {
-                const auto mimeGroup = mime.leftRef(mime.length()-1);
-                if(mimeType.startsWith(mimeGroup))
-                    return plugin.fileName();
+                const auto mimeGroup = QStringView(mime).left(mime.length()-1);
+                if(mimeType.startsWith(mimeGroup)) {
+                    return plugin;
+                }
             }
         }
     }
 
-    return QString();
+    return {};
 }
 
 float ThumbnailProtocol::sequenceIndex() const {
@@ -665,7 +643,7 @@ ThumbCreatorWithMetadata* ThumbnailProtocol::getThumbCreator(const QString& plug
     // Don't use KPluginFactory here, this is not a QObject and
     // neither is ThumbCreator
     ThumbCreator *creator = nullptr;
-    QLibrary library(KPluginLoader::findPlugin((plugin)));
+    QLibrary library(QPluginLoader(plugin).fileName());
     if (library.load()) {
         auto createFn = (newCreator)library.resolve("new_creator");
         if (createFn) {
@@ -679,16 +657,13 @@ ThumbCreatorWithMetadata* ThumbnailProtocol::getThumbCreator(const QString& plug
         if (plugin.contains(QLatin1String("kf5") + QDir::separator() + QLatin1String("thumbcreator"))) {
             data = KPluginMetaData(plugin);
         } else {
-            QT_WARNING_PUSH
-            QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
-            QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
-            // TODO KF6 remove this compat codepath
-            const QString constraint = QStringLiteral("Library == '%1'").arg(QFileInfo(plugin).fileName());
-            const KService::List plugins = KServiceTypeTrader::self()->query(QStringLiteral("ThumbCreator"), constraint);
-            if (!plugins.isEmpty()) {
-                data = KPluginInfo(plugins.first()).toMetaData();
+            const QVector<KPluginMetaData> plugins = KIO::PreviewJob::availableThumbnailerPlugins();
+            auto findPluginIt = std::find_if(plugins.begin(), plugins.end(), [&plugin](const KPluginMetaData &data) {
+                return data.pluginId() == plugin;
+            });
+            if (findPluginIt != plugins.end()) {
+                data = *findPluginIt;
             }
-            QT_WARNING_POP
         }
         if (!data.isValid()) {
             qCWarning(KIO_THUMBNAIL_LOG) << "Plugin not found:" << plugin;
@@ -732,11 +707,11 @@ bool ThumbnailProtocol::createSubThumbnail(QImage &thumbnail, const QString &fil
 {
     auto getSubCreator = [&filePath, this]() -> ThumbCreatorWithMetadata* {
         const QMimeDatabase db;
-        const QString subPlugin = pluginForMimeType(db.mimeTypeForFile(filePath).name());
-        if (subPlugin.isEmpty() || !m_enabledPlugins.contains(subPlugin)) {
+        const KPluginMetaData  subPlugin = pluginForMimeType(db.mimeTypeForFile(filePath).name());
+        if (!subPlugin.isValid() || !m_enabledPlugins.contains(subPlugin.pluginId())) {
             return nullptr;
         }
-        return getThumbCreator(subPlugin);
+        return getThumbCreator(subPlugin.fileName());
     };
 
     const auto maxDimension = qMin(1024, 512 * m_devicePixelRatio);
@@ -786,11 +761,7 @@ bool ThumbnailProtocol::createSubThumbnail(QImage &thumbnail, const QString &fil
 
                 // The thumbnail has been created successfully. Check if we can store
                 // the thumbnail to the cache for future access.
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 83, 0)
                 if (subCreator->cacheThumbnail && metaData("cache").toInt() && !thumbnail.isNull()) {
-#else
-                if (subCreator->cacheThumbnail && !thumbnail.isNull()) {
-#endif
                     QString thumbPath;
                     const int wants = std::max(thumbnail.width(), thumbnail.height());
                     for (const auto &pool : pools) {
